@@ -292,6 +292,7 @@ class FtTool(object):
                     product_name = "盖亚青柯cats测试"
                 """
                 
+                
                 path_head = product_name + '_' + trade_acc
                 for file in csv_path.glob("*.csv"):
                     if file.stem.startswith(path_head):
@@ -465,16 +466,19 @@ class FtTool(object):
                                 if actual_yd_pos_long > 0:
                                     query_positions = {'accountName': account_name, 'ticker': ticker, 'sid' :  {'$ne' : sid}}
                                     position_for_update = equity_position_collection.find_one(query_positions)
-                                    yd_pos_long = position_for_update['yd_pos_long'] + actual_yd_pos_long
-                                    actual_yd_pos_long = position_for_update['actual_yd_pos_long'] + actual_yd_pos_long
-                                    _id = position_for_update['_id']
-                                    _query = {'_id': _id}
-                                    data_to_update ={
-                                        'yd_pos_long' : yd_pos_long,
-                                        'actual_yd_pos_long' : actual_yd_pos_long
-                                    }
-                                    new_data = {"$set": data_to_update}
-                                    res = equity_position_collection.update_one(_query, new_data)
+                                    if position_for_update == None:
+                                        self.logger.warning("[sync_position_add] one_pos")
+                                    else:
+                                        yd_pos_long = position_for_update['yd_pos_long'] + actual_yd_pos_long
+                                        actual_yd_pos_long = position_for_update['actual_yd_pos_long'] + actual_yd_pos_long
+                                        _id = position_for_update['_id']
+                                        _query = {'_id': _id}
+                                        data_to_update ={
+                                            'yd_pos_long' : yd_pos_long,
+                                            'actual_yd_pos_long' : actual_yd_pos_long
+                                        }
+                                        new_data = {"$set": data_to_update}
+                                        res = equity_position_collection.update_one(_query, new_data)
                                 elif actual_yd_pos_long < 0:
                                     query_positions = {'accountName': account_name, 'ticker': ticker, 'sid' : {'$ne' : sid}}
                                     ticker_positions = equity_position_collection.find(query_positions)
@@ -622,7 +626,7 @@ class FtTool(object):
                         query = {'ticker': ticker, 'accountName': accountName}
                         EquityPosition_targets = self.order_info_db[acc]['EquityPosition'].find(query)
                         if EquityPosition_targets.count() == 0 and not pos['ticker'] == '' and not total_vol == 0:
-                            self.add_position_for_debug(acc, pos, ticker, td_vol, yd_vol, accountName)
+                            self.add_position_for_new_order(acc, pos, ticker, td_vol, yd_vol, accountName)
                         elif not pos['ticker'] == '':
                             td_vol_indb = 0
                             yd_vol_indb = 0
@@ -675,6 +679,49 @@ class FtTool(object):
             self.logger.error(f'[update_position] (exception){err}')
             exc_type, exc_value, exc_traceback = sys.exc_info()
             traceback.print_exception(exc_type, exc_value, exc_traceback, limit=None, file=sys.stdout)
+            
+    def add_position_for_new_order(self, acc, pos, ticker, td_vol, yd_vol, accountName):
+        try:
+            sid = '[ADD]' + self.generate_sid(ticker)
+            collection_for_sid =  self.order_info_db[acc]['ft_proposed_target']
+            query_for_find_sid = {"stock_code": ticker, "target_account_name": accountName}
+            new_target = collection_for_sid.find_one(query_for_find_sid)
+            if not new_target == None:
+                sid = new_target['sid']
+                
+            collection = self.order_info_db[acc]['EquityPosition']
+            #collection = self.test_trading_account['EquityPosition']
+            exchange = int(pos['exchange'])
+            order_collection = self.order_info_db[acc]['ft_order']
+    
+            total_vol = td_vol + yd_vol
+            self.logger.warning(
+                f'[add_position_for_new_order] add_position (ticker){ticker} (total_vol){total_vol}')
+            record = {}
+            record['accountName'] = accountName
+            record['ticker'] = ticker
+            record['yd_pos_long'] = yd_vol
+            record['yd_pos_short'] = 0
+            record['td_pos_long'] = td_vol
+            record['td_pos_short'] = 0
+            record['actual_td_pos_long'] = td_vol
+            record['actual_yd_pos_long'] = yd_vol
+            # 持仓平均成本 非凸只返回仓位,无法计算cost,和market_value
+            record['cost'] = 0
+            record['mkt_value'] = 0
+            record['enter_date'] = datetime.now(timezone.utc)
+            record['holding_days'] = 0 
+            record['sid'] = sid
+            record['exchange'] = exchange
+            filter = {'sid' : record['sid'], 'accountName': accountName}
+            res = collection.replace_one(filter, record, True) 
+            self.logger.info(f"[add_position_for_new_order] (res){res} (msg){record}")
+            
+        except Exception as e:
+            err = traceback.format_exc()
+            self.logger.error(f'[add_position_for_new_order] (exception){err}')
+            exc_type, exc_value, exc_traceback = sys.exc_info()
+            traceback.print_exception(exc_type, exc_value, exc_traceback, limit=None, file=sys.stdout)
 
     def add_position_for_debug(self, acc, pos, ticker, td_vol, yd_vol, accountName):
         try:
@@ -747,4 +794,4 @@ if __name__ == "__main__":
 
     td = FtTool(args.config_filename, args.update_trade_date, args.sync_pos, args.sync_trade, args.sync_add, args.sync_trade_in_trading)
     
-    td.start()  
+    td.start()  
\ No newline at end of file
